pub enum TensorRowMapping {
BatchTokens,
}Expand description
Mapping between tensor rows and the submitted decode batch.
Variants
BatchTokens
Rows correspond in order to logical token entries in the decode batch.