LLamaCppError

Enum LLamaCppError 

pub enum LLamaCppError {
    BackendAlreadyInitialized,
    ChatTemplateError(ChatTemplateError),
    DecodeError(DecodeError),
    EncodeError(EncodeError),
    LlamaModelLoadError(LlamaModelLoadError),
    LlamaContextLoadError(LlamaContextLoadError),
    BatchAddError(BatchAddError),
    EmbeddingError(EmbeddingsError),
}
All errors that can occur in the llama-cpp crate.

Variants



BackendAlreadyInitialized

The backend was already initialized. This can generally be ignored as initializing the backend is idempotent.



ChatTemplateError(ChatTemplateError)

There was an error while get the chat template from model.



DecodeError(DecodeError)

There was an error while decoding a batch.



EncodeError(EncodeError)

There was an error while encoding a batch.



LlamaModelLoadError(LlamaModelLoadError)

There was an error loading a model.



LlamaContextLoadError(LlamaContextLoadError)

There was an error creating a new model context.



BatchAddError(BatchAddError)

There was an error adding a token to a batch.



EmbeddingError(EmbeddingsError)