pub enum FitParamsError {
InvalidPath,
CouldNotFit,
Failed,
}Expand description
Errors from fit_params.
Variants
InvalidPath
The model path could not be encoded as a C string.
CouldNotFit
Fitting could not find allocations that fit device memory.
Failed
A hard error occurred (e.g. model file missing).