model_meta_key_str

Function model_meta_key_str 

pub fn model_meta_key_str(key: u32) -> String
Get the string representation of a model metadata key.

Panics

Panics if the returned string is not valid UTF-8.