pub unsafe fn opt_init(
ctx: *mut llama_context,
model: *mut llama_model,
params: llama_opt_params,
)Expand description
Initialize optimizer state for fine-tuning.
Safety
The context and model must be valid and compatible.
pub unsafe fn opt_init(
ctx: *mut llama_context,
model: *mut llama_model,
params: llama_opt_params,
)Initialize optimizer state for fine-tuning.
The context and model must be valid and compatible.