pub unsafe fn tensor_get(tensor: &GgmlTensor, data: &mut [u8])Expand description
Get tensor data into a byte slice.
Safety
The tensor must be allocated and the buffer must be large enough.
pub unsafe fn tensor_get(tensor: &GgmlTensor, data: &mut [u8])Get tensor data into a byte slice.
The tensor must be allocated and the buffer must be large enough.