pub unsafe fn tensor_set(tensor: &GgmlTensor, data: &[u8])Expand description
Set tensor data from a byte slice.
Safety
The tensor must be allocated and the data must be the correct size.
pub unsafe fn tensor_set(tensor: &GgmlTensor, data: &[u8])Set tensor data from a byte slice.
The tensor must be allocated and the data must be the correct size.