GgmlBackend

Struct GgmlBackend 

pub struct GgmlBackend { /* private fields */ }
A safe wrapper around ggml_backend.

Implementations

Source

impl GgmlBackend

pub fn cpu() -> Self

Create a CPU backend.

pub fn set_n_threads(&self, n_threads: i32)

Set the number of threads for the CPU backend.

pub fn alloc_ctx_tensors(&self, ctx: &GgmlContext) -> *mut ggml_backend_buffer

Allocate all tensors in a context on this backend.

Returns the buffer handle which must be kept alive.

pub fn graph_compute(&self, graph: &mut GgmlGraph)

Compute a graph.

pub fn default_buffer_type(&self) -> ggml_backend_buffer_type_t

Get the default buffer type for this backend.

pub fn as_ptr(&self) -> ggml_backend_t

Get the raw backend pointer.