Module model

Module model 

A safe wrapper around llama_model.

Modules

params
A safe wrapper around llama_model_params.

Structs

LlamaChatMessage
A Safe wrapper around llama_chat_message
LlamaLoraAdapter
A safe wrapper around llama_adapter_lora.
LlamaModel
A safe wrapper around llama_model.
LlamaVocab
A safe wrapper around llama_vocab.

Enums

AddBos
How to determine if we should prepend a bos token to tokens
LlamaTokenTypeFromIntError
Error that occurs when trying to convert a llama_vocab_type to a VocabType.
Special
How to determine if we should tokenize special tokens
VocabType
Defines the possible types of vocabulary used by the model.