#[repr(u32)]pub enum VocabType {
BPE = 2,
SPM = 1,
}Expand description
Defines the possible types of vocabulary used by the model.
The model may use different types of vocabulary depending on the tokenization method chosen during training.
This enum represents these types, specifically BPE (Byte Pair Encoding) and SPM (SentencePiece).
Variants
BPE: Byte Pair Encoding, a common tokenization method used in NLP tasks.SPM:SentencePiece, another popular tokenization method for NLP models.
Example
use llama_cpp_4::model::VocabType;
let vocab_type = VocabType::BPE;
match vocab_type {
VocabType::BPE => println!("The model uses Byte Pair Encoding (BPE)"),
VocabType::SPM => println!("The model uses SentencePiece (SPM)"),
}Variants