pub enum QuantPreviewError {
Init,
NotQuantizable(String),
Nul(NulError),
MockModel,
}Expand description
Failure building or using a QuantPreview.
Variants
Init
llama.cpp could not build a quantization state for this model.
NotQuantizable(String)
A tensor that would not be quantized was passed to
QuantPreview::compute_types.
Nul(NulError)
The mock-model descriptor contained an interior NUL byte.
MockModel
llama.cpp could not build a model from the descriptor.