pub fn resolve_docker(reference: &str) -> Result<String, RuntimeError>Expand description
Resolve a Docker model reference to a local path.
Errors
Returns RuntimeError::Failed if resolution fails, or
RuntimeError::Nul for an interior NUL.
pub fn resolve_docker(reference: &str) -> Result<String, RuntimeError>Resolve a Docker model reference to a local path.
Returns RuntimeError::Failed if resolution fails, or
RuntimeError::Nul for an interior NUL.