Module speculative

Module speculative 

Shared exact-state contracts for speculative draft sessions.

Enums

SpeculativeStateError
Failure while capturing or restoring versioned speculative state.

Constants

MAX_SPECULATIVE_DRAFT_TOKENS
Maximum tokens requested from one speculative draft boundary.
MAX_SPECULATIVE_PROMPT_TOKENS
Maximum prompt tokens copied into one speculative session.
MAX_SPECULATIVE_SEQUENCES
Maximum concurrent sequence slots allocated by one speculative session.
MAX_SPECULATIVE_STATE_BYTES
Maximum speculative continuation bytes copied through the safe API.