LlamaTokenData

Struct LlamaTokenData 

pub struct LlamaTokenData { /* private fields */ }
A transparent wrapper around llama_token_data.

Do not rely on repr(transparent) for this type. It should be considered an implementation detail and may change across minor versions.

Implementations

Source

impl LlamaTokenData

pub fn new(LlamaToken: LlamaToken, logit: f32, p: f32) -> Self

Create a new token data from a token, logit, and probability.

let token = LlamaToken::new(1);
let token_data = LlamaTokenData::new(token, 1.0, 1.0);
pub fn id(&self) -> LlamaToken

Get the token’s id

let token = LlamaToken::new(1);
let token_data = LlamaTokenData::new(token, 1.0, 1.0);
assert_eq!(token_data.id(), token);
pub fn logit(&self) -> f32

Get the token’s logit

let token = LlamaToken::new(1);
let token_data = LlamaTokenData::new(token, 1.0, 1.0);
assert_eq!(token_data.logit(), 1.0);
pub fn p(&self) -> f32

Get the token’s probability

let token = LlamaToken::new(1);
let token_data = LlamaTokenData::new(token, 1.0, 1.0);
assert_eq!(token_data.p(), 1.0);
pub fn set_id(&mut self, id: LlamaToken)

Set the token’s id

let token = LlamaToken::new(1);
let mut token_data = LlamaTokenData::new(token, 1.0, 1.0);
token_data.set_id(LlamaToken::new(2));
assert_eq!(token_data.id(), LlamaToken::new(2));
pub fn set_logit(&mut self, logit: f32)

Set the token’s logit

let token = LlamaToken::new(1);
let mut token_data = LlamaTokenData::new(token, 1.0, 1.0);
token_data.set_logit(2.0);
assert_eq!(token_data.logit(), 2.0);
pub fn set_p(&mut self, p: f32)

Set the token’s probability

let token = LlamaToken::new(1);
let mut token_data = LlamaTokenData::new(token, 1.0, 1.0);
token_data.set_p(2.0);
assert_eq!(token_data.p(), 2.0);