#[non_exhaustive]pub enum DetokenizeError {
TokenToBytes(TokenToStringError),
InvalidUtf8(Utf8Error),
IncompleteUtf8(Vec<u8>),
}Expand description
An error produced while streaming detokenization.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TokenToBytes(TokenToStringError)
A token could not be converted to its raw piece bytes.
InvalidUtf8(Utf8Error)
The accumulated bytes contained a genuinely invalid UTF-8 sequence, as opposed to a merely incomplete trailing sequence (which is buffered).
IncompleteUtf8(Vec<u8>)
StreamDetokenizer::finish was called while an incomplete trailing
UTF-8 sequence was still buffered. Carries the leftover bytes.