pub struct LlamaContext<'a> {
pub model: &'a LlamaModel,
/* private fields */
}Expand description
A safe wrapper around the llama_context C++ context.
This struct provides a safe interface to interact with the llama_context used by the LlamaModel.
It encapsulates the raw C++ context pointer and provides additional fields for managing the model and
context-specific settings like embeddings and logits.
The LlamaContext struct ensures that the C++ context is always valid by using the NonNull type for
the context pointer, preventing it from being null. The struct also holds a reference to the model
(LlamaModel) that the context is tied to, along with some internal state like whether embeddings are enabled
and the initialized logits for the context.
Fields
context: A non-null pointer to the raw C++llama_context. This is the main context used for interacting with the model.model: A reference to theLlamaModelassociated with this context. This model provides the data and parameters that the context interacts with.initialized_logits: A vector used to store the initialized logits. These are used in the model’s processing and are kept separate from the context data.embeddings_enabled: A boolean flag indicating whether embeddings are enabled in the context. This is useful for controlling whether embedding data is generated during the interaction with the model.
Fields
model: &'a LlamaModela reference to the contexts model.
Implementations
Sourceimpl LlamaContext<'_>
impl LlamaContext<'_>
Sourcepub fn copy_cache(&mut self, src: i32, dest: i32, size: i32)
pub fn copy_cache(&mut self, src: i32, dest: i32, size: i32)
Copy the cache from one sequence to another.
Parameters
src- The sequence id to copy the cache from.dest- The sequence id to copy the cache to.size- The size of the cache to copy.
Sourcepub fn copy_kv_cache_seq(
&mut self,
src: i32,
dest: i32,
p0: Option<u32>,
p1: Option<u32>,
) -> Result<(), KvCacheConversionError>
pub fn copy_kv_cache_seq( &mut self, src: i32, dest: i32, p0: Option<u32>, p1: Option<u32>, ) -> Result<(), KvCacheConversionError>
Copy the cache from one sequence to another.
Parameters
src- The sequence id to copy the cache from.dest- The sequence id to copy the cache to.p0- The start position of the cache to clear. IfNone, the entire cache is copied up top1.p1- The end position of the cache to clear. IfNone, the entire cache is copied starting fromp0.
Errors
Returns KvCacheConversionError if either position exceeds the maximum i32 value.
Sourcepub fn clear_kv_cache_seq(
&mut self,
src: Option<u32>,
p0: Option<u32>,
p1: Option<u32>,
) -> Result<bool, KvCacheConversionError>
pub fn clear_kv_cache_seq( &mut self, src: Option<u32>, p0: Option<u32>, p1: Option<u32>, ) -> Result<bool, KvCacheConversionError>
Clear the kv cache for the given sequence within the specified range [p0, p1).
Returns false only when partial sequence removals fail. Full sequence removals always succeed.
Parameters
src- The sequence id to clear the cache for. IfNone, matches all sequencesp0- The start position of the cache to clear. IfNone, the entire cache is cleared up top1.p1- The end position of the cache to clear. IfNone, the entire cache is cleared fromp0.
Errors
Returns KvCacheConversionError if the sequence id or either position exceeds the maximum i32 value.
Sourcepub fn clear_kv_cache(&mut self)
pub fn clear_kv_cache(&mut self)
Clear the KV cache
Sourcepub fn llama_kv_cache_seq_keep(&mut self, seq_id: i32)
pub fn llama_kv_cache_seq_keep(&mut self, seq_id: i32)
Removes all tokens that do not belong to the specified sequence
Parameters
seq_id- The sequence id to keep
Sourcepub fn kv_cache_seq_add(
&mut self,
seq_id: i32,
p0: Option<u32>,
p1: Option<u32>,
delta: i32,
) -> Result<(), KvCacheConversionError>
pub fn kv_cache_seq_add( &mut self, seq_id: i32, p0: Option<u32>, p1: Option<u32>, delta: i32, ) -> Result<(), KvCacheConversionError>
Adds relative position “delta” to all tokens that belong to the specified sequence and have positions in [p0, p1).
Parameters
seq_id- The sequence id to updatep0- The start position of the cache to update. IfNone, the entire cache is updated up top1.p1- The end position of the cache to update. IfNone, the entire cache is updated starting fromp0.delta- The relative position to add to the tokens
Errors
Returns KvCacheConversionError if either position exceeds the maximum i32 value.
Sourcepub fn kv_cache_seq_div(
&mut self,
seq_id: i32,
p0: Option<u32>,
p1: Option<u32>,
d: NonZeroU8,
) -> Result<(), KvCacheConversionError>
pub fn kv_cache_seq_div( &mut self, seq_id: i32, p0: Option<u32>, p1: Option<u32>, d: NonZeroU8, ) -> Result<(), KvCacheConversionError>
Integer division of the positions by factor of d > 1.
Parameters
seq_id- The sequence id to updatep0- The start position of the cache to update. IfNone, the entire cache is updated up top1.p1- The end position of the cache to update. IfNone, the entire cache is updated starting fromp0.d- The factor to divide the positions by
Errors
Returns KvCacheConversionError if either position exceeds the maximum i32 value.
Sourcepub fn kv_cache_seq_pos_max(&self, seq_id: i32) -> i32
pub fn kv_cache_seq_pos_max(&self, seq_id: i32) -> i32
Returns the largest position present in the KV cache for the specified sequence
Parameters
seq_id- The sequence id to get the max position for
Sourceimpl LlamaContext<'_>
impl LlamaContext<'_>
Sourcepub fn save_session_file(
&self,
path_session: impl AsRef<Path>,
tokens: &[LlamaToken],
) -> Result<(), SaveSessionError>
pub fn save_session_file( &self, path_session: impl AsRef<Path>, tokens: &[LlamaToken], ) -> Result<(), SaveSessionError>
Save the current session to a file.
Parameters
path_session- The file to save to.tokens- The tokens to associate the session with. This should be a prefix of a sequence of tokens that the context has processed, so that the relevant KV caches are already filled.
Errors
Fails if the path is not a valid utf8, is not a valid c string, or llama.cpp fails to save the session file.
Sourcepub fn load_session_file(
&mut self,
path_session: impl AsRef<Path>,
max_tokens: usize,
) -> Result<Vec<LlamaToken>, LoadSessionError>
pub fn load_session_file( &mut self, path_session: impl AsRef<Path>, max_tokens: usize, ) -> Result<Vec<LlamaToken>, LoadSessionError>
Load a session file into the current context.
You still need to pass the returned tokens to the context for inference to work. What this function buys you is that the KV caches are already filled with the relevant data.
Parameters
path_session- The file to load from. It must be a session file from a compatible context, otherwise the function will error.max_tokens- The maximum token length of the loaded session. If the session was saved with a longer length, the function will error.
Errors
Fails if the path is not a valid utf8, is not a valid c string, or llama.cpp fails to load the session file. (e.g. the file does not exist, is not a session file, etc.)
Sourcepub fn get_state_size(&self) -> usize
pub fn get_state_size(&self) -> usize
Returns the maximum size in bytes of the state (rng, logits, embedding
and kv_cache) - will often be smaller after compacting tokens
Sourcepub unsafe fn copy_state_data(&self, dest: *mut u8) -> usize
pub unsafe fn copy_state_data(&self, dest: *mut u8) -> usize
Copies the state to the specified destination address.
Returns the number of bytes copied
Safety
Destination needs to have allocated enough memory.
Sourcepub unsafe fn set_state_data(&mut self, src: &[u8]) -> usize
pub unsafe fn set_state_data(&mut self, src: &[u8]) -> usize
Set the state reading from the specified address Returns the number of bytes read
Safety
help wanted: not entirely sure what the safety requirements are here.
Sourceimpl<'model> LlamaContext<'model>
impl<'model> LlamaContext<'model>
Sourcepub fn n_batch(&self) -> u32
pub fn n_batch(&self) -> u32
Gets the max number of logical tokens that can be submitted to decode. Must be greater than or equal to n_ubatch.
Sourcepub fn n_ubatch(&self) -> u32
pub fn n_ubatch(&self) -> u32
Gets the max number of physical tokens (hardware level) to decode in batch. Must be less than or equal to n_batch.
Sourcepub fn decode(&mut self, batch: &mut LlamaBatch) -> Result<(), DecodeError>
pub fn decode(&mut self, batch: &mut LlamaBatch) -> Result<(), DecodeError>
Decodes the batch.
Errors
DecodeErrorif the decoding failed.
Panics
- the returned
std::ffi::c_intfrom llama-cpp does not fit into a i32 (this should never happen on most systems)
Sourcepub fn encode(&mut self, batch: &mut LlamaBatch) -> Result<(), EncodeError>
pub fn encode(&mut self, batch: &mut LlamaBatch) -> Result<(), EncodeError>
Encodes the batch.
Errors
EncodeErrorif the decoding failed.
Panics
- the returned
std::ffi::c_intfrom llama-cpp does not fit into a i32 (this should never happen on most systems)
Sourcepub fn pooling_type(&self) -> LlamaPoolingType
pub fn pooling_type(&self) -> LlamaPoolingType
Return Pooling type for Llama’s Context
Sourcepub fn embeddings_seq_ith(&self, i: i32) -> Result<&[f32], EmbeddingsError>
pub fn embeddings_seq_ith(&self, i: i32) -> Result<&[f32], EmbeddingsError>
Get the embeddings for the ith sequence in the current context.
Returns
A slice containing the embeddings for the last decoded batch.
The size corresponds to the n_embd parameter of the context’s model.
Errors
- When the current context was constructed without enabling embeddings.
- If the current model had a pooling type of
llama_cpp_sys_4::LLAMA_POOLING_TYPE_NONE - If the given sequence index exceeds the max sequence id.
Panics
n_embddoes not fit into a usize
Sourcepub fn embeddings_ith(&self, i: i32) -> Result<&[f32], EmbeddingsError>
pub fn embeddings_ith(&self, i: i32) -> Result<&[f32], EmbeddingsError>
Get the embeddings for the ith token in the current context.
Returns
A slice containing the embeddings for the last decoded batch of the given token.
The size corresponds to the n_embd parameter of the context’s model.
Errors
- When the current context was constructed without enabling embeddings.
- When the given token didn’t have logits enabled when it was passed.
- If the given token index exceeds the max token id.
Panics
n_embddoes not fit into a usize
Sourcepub fn candidates(&self) -> impl Iterator<Item = LlamaTokenData> + '_
pub fn candidates(&self) -> impl Iterator<Item = LlamaTokenData> + '_
Sourcepub fn token_data_array(&self) -> LlamaTokenDataArray
pub fn token_data_array(&self) -> LlamaTokenDataArray
Sourcepub fn get_logits(&self) -> &[f32]
pub fn get_logits(&self) -> &[f32]
Token logits obtained from the last call to decode().
The logits for which batch.logits[i] != 0 are stored contiguously
in the order they have appeared in the batch.
Rows: number of tokens for which batch.logits[i] != 0
Cols: n_vocab
Returns
A slice containing the logits for the last decoded token.
The size corresponds to the n_vocab parameter of the context’s model.
Panics
n_vocabdoes not fit into a usize- token data returned is null
Sourcepub fn candidates_ith(
&self,
i: i32,
) -> impl Iterator<Item = LlamaTokenData> + '_
pub fn candidates_ith( &self, i: i32, ) -> impl Iterator<Item = LlamaTokenData> + '_
Sourcepub fn get_logits_ith(&self, i: i32) -> &[f32]
pub fn get_logits_ith(&self, i: i32) -> &[f32]
Get the logits for the ith token in the context.
Panics
iis greater thann_ctxn_vocabdoes not fit into a usize- logit
iis not initialized.
Sourcepub fn reset_timings(&mut self)
pub fn reset_timings(&mut self)
Reset the timings for the context.
Sourcepub fn timings(&mut self) -> PerfContextData
pub fn timings(&mut self) -> PerfContextData
Returns the timings for the context.
Sourcepub fn lora_adapter_set(
&self,
adapter: &mut LlamaLoraAdapter,
scale: f32,
) -> Result<(), LlamaLoraAdapterSetError>
pub fn lora_adapter_set( &self, adapter: &mut LlamaLoraAdapter, scale: f32, ) -> Result<(), LlamaLoraAdapterSetError>
Sourcepub fn lora_adapter_remove(
&self,
_adapter: &mut LlamaLoraAdapter,
) -> Result<(), LlamaLoraAdapterRemoveError>
pub fn lora_adapter_remove( &self, _adapter: &mut LlamaLoraAdapter, ) -> Result<(), LlamaLoraAdapterRemoveError>
Remove all lora adapters from the context.
Note: as of llama.cpp b8249 the per-adapter remove API was replaced by
llama_set_adapters_lora which operates on the full adapter list at once.
Calling this function clears all adapters currently set on the context.
Errors
See LlamaLoraAdapterRemoveError for more information.
Sourceimpl LlamaContext<'_>
impl LlamaContext<'_>
Sourcepub fn as_ptr(&self) -> *mut llama_context
pub fn as_ptr(&self) -> *mut llama_context
Expose the raw llama_context pointer for use with mtmd helpers.
Safety
The pointer is valid for the lifetime of this LlamaContext and must
not be freed by the caller.