log_set

Function log_set 

pub unsafe fn log_set(callback: ggml_log_callback, user_data: *mut c_void)
Set the log callback.

Safety

The callback and user data must remain valid for the lifetime of the application or until the callback is replaced.