pub struct GgmlBackend { /* private fields */ }Expand description
A safe wrapper around ggml_backend.
Implementations
Sourceimpl GgmlBackend
impl GgmlBackend
Sourcepub fn set_n_threads(&self, n_threads: i32)
pub fn set_n_threads(&self, n_threads: i32)
Set the number of threads for the CPU backend.
Sourcepub fn alloc_ctx_tensors(&self, ctx: &GgmlContext) -> *mut ggml_backend_buffer
pub fn alloc_ctx_tensors(&self, ctx: &GgmlContext) -> *mut ggml_backend_buffer
Allocate all tensors in a context on this backend.
Returns the buffer handle which must be kept alive.
Sourcepub fn graph_compute(&self, graph: &mut GgmlGraph)
pub fn graph_compute(&self, graph: &mut GgmlGraph)
Compute a graph.
Sourcepub fn default_buffer_type(&self) -> ggml_backend_buffer_type_t
pub fn default_buffer_type(&self) -> ggml_backend_buffer_type_t
Get the default buffer type for this backend.
Sourcepub fn as_ptr(&self) -> ggml_backend_t
pub fn as_ptr(&self) -> ggml_backend_t
Get the raw backend pointer.