A safe wrapper around llama_model.
Modules
- params
- A safe wrapper around
llama_model_params.
Structs
- Llama
Chat Message - A Safe wrapper around
llama_chat_message - Llama
Lora Adapter - A safe wrapper around
llama_adapter_lora. - Llama
Model - A safe wrapper around
llama_model. - Llama
Vocab - A safe wrapper around
llama_vocab.
Enums
- AddBos
- How to determine if we should prepend a bos token to tokens
- Llama
Token Type From IntError - Error that occurs when trying to convert a
llama_vocab_typeto aVocabType. - Special
- How to determine if we should tokenize special tokens
- Vocab
Type - Defines the possible types of vocabulary used by the model.