pub enum LlamaTokenTypeFromIntError {
UnknownValue(llama_vocab_type),
}Expand description
Error that occurs when trying to convert a llama_vocab_type to a VocabType.
This error is raised when the integer value returned by the system does not correspond to a known vocabulary type.
Variants
UnknownValue: The error is raised when the value is not a validllama_vocab_type. The invalid value is returned with the error.
Example
use llama_cpp_4::model::LlamaTokenTypeFromIntError;
let invalid_value = 999; // Not a valid vocabulary type
let error = LlamaTokenTypeFromIntError::UnknownValue(invalid_value);
println!("Error: {}", error);Variants
UnknownValue(llama_vocab_type)
The value is not a valid llama_token_type. Contains the int value that was invalid.