pub enum MtmdError {
ContextCreateFailed,
BitmapCreateFailed,
InvalidPath(NulError),
PathNotUtf8,
TokenizeError(i32),
EncodeError(i32),
EvalError(i32),
}Expand description
All errors that can be returned by the mtmd module.
Variants
ContextCreateFailed
The context could not be created (e.g. bad mmproj file).
BitmapCreateFailed
The bitmap could not be created.
InvalidPath(NulError)
A path could not be converted to a valid C string (embedded NUL byte or non-UTF-8).
PathNotUtf8
A path was not representable as UTF-8.
TokenizeError(i32)
mtmd_tokenize returned an error code.
EncodeError(i32)
mtmd_encode_chunk returned a non-zero code.
EvalError(i32)
mtmd_helper_eval_chunks (or single-chunk variant) returned a non-zero code.