MtmdInputText

Struct MtmdInputText 

pub struct MtmdInputText<'a> { /* private fields */ }
Text input for MtmdContext::tokenize.

The prompt string must contain the media marker (see MtmdContext::default_marker) once for every bitmap to be embedded.

Implementations

Source

impl<'a> MtmdInputText<'a>

pub fn new(text: &'a str, add_special: bool, parse_special: bool) -> Self

Create a new MtmdInputText.

  • text – the prompt (must not contain interior NUL bytes)
  • add_special – whether to add BOS/EOS tokens
  • parse_special – whether to parse special tokens embedded in the text
Panics

Panics if text contains an interior NUL byte.

pub fn try_new( text: &'a str, add_special: bool, parse_special: bool, ) -> Result<Self, NulError>

Try to create a new MtmdInputText, returning an error if text contains an interior NUL byte.

Errors

Returns std::ffi::NulError if text contains a NUL byte.